@@ -37,7 +37,6 @@
 #include <QGuiApplication>
 #include <QSortFilterProxyModel>
 #include <QTimer>
-#include <QSessionManager>
 
 // KDE includes
 #include <KAboutApplicationDialog>
@@ -128,6 +127,12 @@ DiscoverObject::DiscoverObject(CompactMode mode)
 
     connect(m_engine, &QQmlApplicationEngine::objectCreated, this, &DiscoverObject::integrateObject);
     m_engine->load(QUrl(QStringLiteral("qrc:/qml/DiscoverWindow.qml")));
+
+    connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, this, [this](){
+        const auto objs = m_engine->rootObjects();
+        for(auto o: objs)
+            delete o;
+    });
 }
 
 DiscoverObject::~DiscoverObject()
@@ -156,18 +161,13 @@ QStringList DiscoverObject::modes() const
 
 void DiscoverObject::openMode(const QString& _mode)
 {
-    QObject* obj = rootObject();
-    if (!obj) {
-        qWarning() << "could not get the main object";
-        return;
-    }
-
     if(!modes().contains(_mode))
         qWarning() << "unknown mode" << _mode;
 
     QString mode = _mode;
     mode[0] = mode[0].toUpper();
 
+    QObject* obj = rootObject();
     const QByteArray propertyName = "top"+mode.toLatin1()+"Comp";
     const QVariant modeComp = obj->property(propertyName.constData());
     if (!modeComp.isValid())
@@ -242,11 +242,11 @@ void DiscoverObject::openApplication(const QUrl& url)
             auto stream = new StoredResultsStream({ResourcesModel::global()->search(f)});
             connect(stream, &StoredResultsStream::finished, this, [this, url, stream]() {
                 const auto res = stream->resources();
-                if (res.count() >= 1) {
+                if (res.count() == 1) {
                     emit openApplicationInternal(res.first());
                 } else {
                     setRootObjectProperty("defaultStartup", true);
-                    showPassiveNotification(i18n("Couldn't open %1", url.toDisplayString()));
+                    Q_EMIT openErrorPage(i18n("Couldn't open %1", url.toDisplayString()));
                 }
             });
         }
@@ -281,13 +281,6 @@ void DiscoverObject::integrateObject(QObject* object)
 
     object->installEventFilter(this);
     connect(object, &QObject::destroyed, qGuiApp, &QCoreApplication::quit);
-
-    connect(qGuiApp, &QGuiApplication::commitDataRequest, this, [this](QSessionManager &sessionManager) {
-        if (ResourcesModel::global()->isBusy()) {
-            Q_EMIT preventedClose();
-            sessionManager.cancel();
-        }
-    });
 }
 
 bool DiscoverObject::eventFilter(QObject * object, QEvent * event)
