@@ -24,7 +24,6 @@
 #include <QAbstractListModel>
 #include "discovercommon_export.h"
 
-class QTimer;
 class ResourcesUpdatesModel;
 class AbstractResource;
 class UpdateItem;
@@ -92,7 +91,6 @@ private:
     void resourceHasProgressed(AbstractResource* res, qreal progress);
     void activityChanged();
 
-    QTimer* const m_updateSizeTimer;
     QVector<UpdateItem*> m_updateItems;
     ResourcesUpdatesModel* m_updates;
     QList<AbstractResource*> m_resources;
