@@ -29,6 +29,7 @@
 
 #include <KIO/FileCopyJob>
 #include <KUser>
+#include <KLocalizedString>
 
 #include <QCryptographicHash>
 #include <QDir>
@@ -208,7 +209,7 @@ void OdrsReviewsBackend::reviewsFetched()
 
 Rating * OdrsReviewsBackend::ratingForApplication(AbstractResource *app) const
 {
-    if (app->appstreamId().isEmpty()) {
+    if (app->isTechnical()) {
         return nullptr;
     }
 
@@ -244,6 +245,11 @@ void OdrsReviewsBackend::usefulnessSubmitted()
     }
 }
 
+QString OdrsReviewsBackend::userName() const
+{
+    return i18n("%1 (%2)", KUser().property(KUser::FullName).toString(), KUser().loginName());
+}
+
 void OdrsReviewsBackend::submitReview(AbstractResource *res, const QString &summary, const QString &description, const QString &rating)
 {
     QJsonObject map = {{QStringLiteral("app_id"), res->appstreamId()},
