@@ -23,7 +23,7 @@
 #include "FlatpakFetchDataJob.h"
 #include "FlatpakResource.h"
 #include "FlatpakSourcesBackend.h"
-#include "FlatpakJobTransaction.h"
+#include "FlatpakTransaction.h"
 
 #include <resources/StandardBackendUpdater.h>
 #include <resources/SourcesModel.h>
@@ -57,6 +57,7 @@
 #include <QNetworkAccessManager>
 
 #include <glib.h>
+#include "FlatpakSourcesBackend.h"
 
 DISCOVER_BACKEND_PLUGIN(FlatpakBackend)
 
@@ -77,6 +78,7 @@ FlatpakBackend::FlatpakBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(AppStreamIntegration::global()->reviews())
+    , m_fetching(false)
     , m_refreshAppstreamMetadataJobs(0)
     , m_threadPool(new QThreadPool(this))
 {
@@ -545,6 +547,14 @@ private:
     FlatpakRemote* m_remote;
 };
 
+void FlatpakBackend::finishInitialization()
+{
+    loadInstalledApps();
+    checkForUpdates();
+
+    Q_EMIT initialized();
+}
+
 void FlatpakBackend::loadAppsFromAppstreamData()
 {
     for (auto installation : qAsConst(m_installations)) {
@@ -613,7 +623,6 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
         return metadata.components();
     }));
     const auto sourceName = source.name();
-    acquireFetching(true);
     connect(fw, &QFutureWatcher<QList<AppStream::Component>>::finished, this, [this, fw, flatpakInstallation, appstreamIconsPath, sourceName]() {
         const auto components = fw->result();
         foreach (const AppStream::Component& appstreamComponent, components) {
@@ -623,11 +632,8 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
             addResource(resource);
         }
         if (!m_refreshAppstreamMetadataJobs) {
-            loadInstalledApps();
-            checkForUpdates();
-
+            finishInitialization();
         }
-        acquireFetching(false);
         fw->deleteLater();
     });
 }
@@ -662,11 +668,6 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
         if (flatpak_ref_get_kind(FLATPAK_REF(ref)) == FLATPAK_REF_KIND_RUNTIME) {
             continue;
         }
-        const auto res = getAppForInstalledRef(flatpakInstallation, ref);
-        if (res) {
-            res->setState(AbstractResource::Installed);
-            continue;
-        }
 
         const auto name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
         AppStream::Metadata metadata;
@@ -677,9 +678,15 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
             continue;
         }
 
-        auto component = metadata.component();
-        component.setId(name + QLatin1String(".desktop"));
-        FlatpakResource *resource = new FlatpakResource(component, flatpakInstallation, this);
+        const AppStream::Component appstreamComponent(metadata.component());
+
+        const auto res = getAppForInstalledRef(flatpakInstallation, ref);
+        if (res) {
+            res->setState(AbstractResource::Installed);
+            continue;
+        }
+
+        FlatpakResource *resource = new FlatpakResource(appstreamComponent, flatpakInstallation, this);
 
         resource->setIconPath(pathExports);
         resource->setState(AbstractResource::Installed);
@@ -1052,19 +1059,12 @@ void FlatpakBackend::updateAppState(FlatpakInstallation *flatpakInstallation, Fl
     }
 }
 
-void FlatpakBackend::acquireFetching(bool f)
+void FlatpakBackend::setFetching(bool fetching)
 {
-    if (f)
-        m_isFetching++;
-    else
-        m_isFetching--;
-
-    if ((!f && m_isFetching==0) || (f && m_isFetching==1)) {
+    if (m_fetching != fetching) {
+        m_fetching = fetching;
         emit fetchingChanged();
     }
-
-    if (m_isFetching==0)
-        Q_EMIT initialized();
 }
 
 int FlatpakBackend::updatesCount() const
@@ -1075,7 +1075,7 @@ int FlatpakBackend::updatesCount() const
 bool FlatpakBackend::flatpakResourceLessThan(AbstractResource* l, AbstractResource* r)
 {
     return (l->isInstalled() != r->isInstalled()) ? l->isInstalled()
-         : (l->origin() != r->origin()) ? l->origin() < r->origin()
+         : (l->origin() != r->origin()) ? m_sources->originIndex(l->origin()) < m_sources->originIndex(r->origin())
          : l < r;
 }
 
@@ -1095,10 +1095,10 @@ ResultsStream * FlatpakBackend::search(const AbstractResourcesBackend::Filters &
         fetchResourceJob->start();
 
         return stream;
-    } else if(filter.resourceUrl.scheme() == QLatin1String("appstream")) {
-        return findResourceByPackageName(filter.resourceUrl);
-    } else if (!filter.resourceUrl.isEmpty() || !filter.extends.isEmpty())
+    } else if ((!filter.resourceUrl.isEmpty() && filter.resourceUrl.scheme() != QLatin1String("appstream")) || !filter.extends.isEmpty())
         return new ResultsStream(QStringLiteral("FlatpakStream-void"), {});
+    else if(filter.resourceUrl.scheme() == QLatin1String("appstream"))
+        return findResourceByPackageName(filter.resourceUrl);
 
     QVector<AbstractResource*> ret;
     foreach(AbstractResource* r, m_resources) {
@@ -1120,37 +1120,20 @@ ResultsStream * FlatpakBackend::search(const AbstractResourcesBackend::Filters &
 
 ResultsStream * FlatpakBackend::findResourceByPackageName(const QUrl &url)
 {
+    QVector<AbstractResource*> resources;
     if (url.scheme() == QLatin1String("appstream")) {
         if (url.host().isEmpty())
             passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
         else {
-            auto stream = new ResultsStream(QStringLiteral("FlatpakStream"));
-            auto f = [this, stream, url] () {
-                QVector<AbstractResource*> resources;
-                foreach(FlatpakResource* res, m_resources) {
-                    if (QString::compare(res->appstreamId(), url.host(), Qt::CaseInsensitive)==0)
-                        resources << res;
-                }
-                auto f = [this](AbstractResource* l, AbstractResource* r) { return flatpakResourceLessThan(l,r); };
-                std::sort(resources.begin(), resources.end(), f);
-
-                QTimer::singleShot(0, stream, [resources, stream] () {
-                    if (!resources.isEmpty())
-                        Q_EMIT stream->resourcesFound(resources);
-                    stream->finish();
-                });
-            };
-
-            if (isFetching()) {
-                connect(this, &FlatpakBackend::initialized, stream, f);
-            } else {
-                f();
+            foreach(FlatpakResource* res, m_resources) {
+                if (QString::compare(res->appstreamId(), url.host(), Qt::CaseInsensitive)==0)
+                    resources << res;
             }
-
-            return stream;
+            auto f = [this](AbstractResource* l, AbstractResource* r) { return flatpakResourceLessThan(l,r); };
+            std::sort(resources.begin(), resources.end(), f);
         }
     }
-    return new ResultsStream(QStringLiteral("FlatpakStream-packageName-void"), {});
+    return new ResultsStream(QStringLiteral("FlatpakStream"), resources);
 }
 
 AbstractBackendUpdater * FlatpakBackend::backendUpdater() const
@@ -1182,11 +1165,11 @@ Transaction* FlatpakBackend::installApplication(AbstractResource *app, const Add
         return nullptr;
     }
 
-    FlatpakJobTransaction *transaction = nullptr;
+    FlatpakTransaction *transaction = nullptr;
     FlatpakInstallation *installation = resource->installation();
 
     if (resource->propertyState(FlatpakResource::RequiredRuntime) == FlatpakResource::NotKnownYet && resource->type() == FlatpakResource::DesktopApp) {
-        transaction = new FlatpakJobTransaction(resource, Transaction::InstallRole, true);
+        transaction = new FlatpakTransaction(resource, Transaction::InstallRole, true);
         connect(resource, &FlatpakResource::propertyStateChanged, [resource, transaction, this] (FlatpakResource::PropertyKind kind, FlatpakResource::PropertyState state) {
             if (kind != FlatpakResource::RequiredRuntime) {
                 return;
@@ -1203,13 +1186,13 @@ Transaction* FlatpakBackend::installApplication(AbstractResource *app, const Add
     } else {
         FlatpakResource *runtime = getRuntimeForApp(resource);
         if (runtime && !runtime->isInstalled()) {
-            transaction = new FlatpakJobTransaction(resource, runtime, Transaction::InstallRole);
+            transaction = new FlatpakTransaction(resource, runtime, Transaction::InstallRole);
         } else {
-            transaction = new FlatpakJobTransaction(resource, Transaction::InstallRole);
+            transaction = new FlatpakTransaction(resource, Transaction::InstallRole);
         }
     }
 
-    connect(transaction, &FlatpakJobTransaction::statusChanged, [this, installation, resource] (Transaction::Status status) {
+    connect(transaction, &FlatpakTransaction::statusChanged, [this, installation, resource] (Transaction::Status status) {
         if (status == Transaction::Status::DoneStatus) {
             updateAppState(installation, resource);
         }
@@ -1235,9 +1218,9 @@ Transaction* FlatpakBackend::removeApplication(AbstractResource *app)
     }
 
     FlatpakInstallation *installation = resource->installation();
-    FlatpakJobTransaction *transaction = new FlatpakJobTransaction(resource, Transaction::RemoveRole);
+    FlatpakTransaction *transaction = new FlatpakTransaction(resource, Transaction::RemoveRole);
 
-    connect(transaction, &FlatpakJobTransaction::statusChanged, [this, installation, resource] (Transaction::Status status) {
+    connect(transaction, &FlatpakTransaction::statusChanged, [this, installation, resource] (Transaction::Status status) {
         if (status == Transaction::Status::DoneStatus) {
             updateAppSize(installation, resource);
         }
