@@ -50,7 +50,7 @@ public:
     AbstractBackendUpdater * backendUpdater() const override;
     AbstractReviewsBackend * reviewsBackend() const override;
     ResultsStream * search(const AbstractResourcesBackend::Filters & search) override;
-    ResultsStream * findResourceByPackageName(const QUrl &search) override;
+    ResultsStream * findResourceByPackageName(const QUrl &search);
     QList<FlatpakResource*> resources() const { return m_resources.values(); }
     bool isValid() const override;
 
@@ -69,6 +69,9 @@ private Q_SLOTS:
     void onFetchSizeFinished(FlatpakResource *resource, guint64 downloadSize, guint64 installedSize);
     void onFetchUpdatesFinished(FlatpakInstallation *flatpakInstallation, GPtrArray *updates);
 
+Q_SIGNALS: //for tests
+    void initialized();
+
 private:
     bool flatpakResourceLessThan(AbstractResource* l, AbstractResource* r);
     void announceRatingsReady();
