@@ -59,7 +59,7 @@ FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakI
     , m_state(AbstractResource::None)
     , m_type(FlatpakResource::DesktopApp)
 {
-    setObjectName(component.id());
+    setObjectName(packageName());
 
     // Start fetching remote icons during initialization
     const auto icons = m_appdata.icons();
@@ -143,6 +143,7 @@ void FlatpakResource::updateFromRef(FlatpakRef* ref)
     setCommit(QString::fromUtf8(flatpak_ref_get_commit(ref)));
     setFlatpakName(QString::fromUtf8(flatpak_ref_get_name(ref)));
     setType(flatpak_ref_get_kind(ref) == FLATPAK_REF_KIND_APP ? FlatpakResource::DesktopApp : FlatpakResource::Runtime);
+    setObjectName(packageName());
 }
 
 QStringList FlatpakResource::categories()
@@ -183,8 +184,6 @@ QVariant FlatpakResource::icon() const
     } else if (icons.isEmpty()) {
         ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     } else foreach(const AppStream::Icon &icon, icons) {
-        QStringList stock;
-
         switch (icon.kind()) {
             case AppStream::Icon::KindLocal:
             case AppStream::Icon::KindCached: {
@@ -198,9 +197,12 @@ QVariant FlatpakResource::icon() const
                     }
                 }
             }   break;
-            case AppStream::Icon::KindStock:
-                stock += icon.name();
+            case AppStream::Icon::KindStock: {
+                const auto ret = QIcon::fromTheme(icon.name());
+                if (!ret.isNull())
+                    return ret;
                 break;
+            }
             case AppStream::Icon::KindRemote: {
                 const QString fileName = iconCachePath(icon);
                 if (QFileInfo::exists(fileName)) {
@@ -211,11 +213,12 @@ QVariant FlatpakResource::icon() const
             case AppStream::Icon::KindUnknown:
                 break;
         }
-
-        if (ret.isNull()) {
-            ret = QIcon::fromTheme(stock.value(0), QIcon::fromTheme(QStringLiteral("package-x-generic")));
-        }
     }
+
+    if (ret.isNull()) {
+        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+    }
+
     return ret;
 }
 
@@ -245,6 +248,21 @@ QUrl FlatpakResource::homepage()
     return m_appdata.url(AppStream::Component::UrlKindHomepage);
 }
 
+QUrl FlatpakResource::helpURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindHelp);
+}
+
+QUrl FlatpakResource::bugURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindBugtracker);
+}
+
+QUrl FlatpakResource::donationURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindDonation);
+}
+
 QString FlatpakResource::flatpakFileType() const
 {
     return m_flatpakFileType;
@@ -292,7 +310,7 @@ QString FlatpakResource::origin() const
 
 QString FlatpakResource::packageName() const
 {
-    return flatpakName();
+    return flatpakName() + QLatin1Char('/') + arch() + QLatin1Char('/') + branch();
 }
 
 FlatpakResource::PropertyState FlatpakResource::propertyState(FlatpakResource::PropertyKind kind) const
@@ -346,7 +364,7 @@ QString FlatpakResource::sizeDescription()
     }
 }
 
-AbstractResource::State FlatpakResource::state() const
+AbstractResource::State FlatpakResource::state()
 {
     return m_state;
 }
@@ -524,3 +542,13 @@ QUrl FlatpakResource::url() const
 {
     return m_resourceFile.isEmpty() ? QUrl(QStringLiteral("appstream://") + appstreamId()) : m_resourceFile;
 }
+
+QDate FlatpakResource::releaseDate() const
+{
+    if (!m_appdata.releases().isEmpty()) {
+        auto release = m_appdata.releases().constFirst();
+        return release.timestamp().date();
+    }
+
+    return {};
+}
