@@ -84,11 +84,14 @@ public:
     int installedSize() const;
     bool isTechnical() const override;
     QUrl homepage() override;
+    QUrl helpURL() override;
+    QUrl bugURL() override;
+    QUrl donationURL() override;
     QString flatpakFileType() const;
     QString flatpakName() const;
     QString license() override;
     QString longDescription() override;
-    QString name() override;
+    QString name() const override;
     QString origin() const override;
     QString packageName() const override;
     PropertyState propertyState(PropertyKind kind) const;
@@ -97,11 +100,12 @@ public:
     QString section() override;
     int size() override;
     QString sizeDescription() override;
-    AbstractResource::State state() const override;
+    AbstractResource::State state() override;
     ResourceType type() const;
     QString typeAsString() const;
     QString uniqueId() const;
     QUrl url() const override;
+    QDate releaseDate() const override;
 
     FlatpakInstallation* installation() const { return m_installation; }
 
@@ -128,13 +132,14 @@ public:
 //     void setAddonInstalled(const QString& addon, bool installed);
 
     void updateFromRef(FlatpakRef* ref);
+    QString sourceIcon() const override { return QStringLiteral("https://flatpak.org/img/logo.svg"); }
 
 Q_SIGNALS:
     void propertyStateChanged(PropertyKind kind, PropertyState state);
 
 public:
     QList<PackageState> m_addons;
-    AppStream::Component m_appdata;
+    const AppStream::Component m_appdata;
     FlatpakRefKind m_flatpakRefKind;
     QString m_arch;
     QString m_branch;
