@@ -23,7 +23,6 @@
 
 #include <resources/AbstractResource.h>
 #include <KNSCore/EntryInternal>
-#include <QPointer>
 #include <attica/content.h>
 
 #include "discovercommon_export.h"
@@ -36,7 +35,7 @@ public:
     explicit KNSResource(const KNSCore::EntryInternal & c, QStringList categories, KNSBackend* parent);
     ~KNSResource() override;
 
-    AbstractResource::State state() const override;
+    AbstractResource::State state() override;
     QVariant icon() const override;
     QString comment() override;
     QString name() const override;
@@ -65,14 +64,14 @@ public:
     void invokeApplication() const override;
 
     QUrl url() const override;
-
-    Rating* ratingInstance();
+    QString executeLabel() const override;
+    QString sourceIcon() const override { return QStringLiteral("get-hot-new-stuff"); }
+    QDate releaseDate() const override;
 
 private:
     const QStringList m_categories;
     KNSCore::EntryInternal m_entry;
     KNS3::Entry::Status m_lastStatus;
-    QPointer<Rating> m_rating;
 };
 
 #endif // KNSRESOURCE_H
