@@ -31,8 +31,6 @@
 #include <QStandardPaths>
 #include <QDebug>
 #include "config-paths.h"
-#include <PackageKit/Daemon>
-#include <utils.h>
 
 AppPackageKitResource::AppPackageKitResource(const AppStream::Component& data, const QString &packageName, PackageKitBackend* parent)
     : PackageKitResource(packageName, QString(), parent)
@@ -46,14 +44,9 @@ QString AppPackageKitResource::name() const
     QString ret;
     if (!m_appdata.extends().isEmpty()) {
         auto components = backend()->componentsById(m_appdata.extends().constFirst());
-
-        if (components.isEmpty())
-            qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
-        else
-            ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
-    }
-
-    if (ret.isEmpty())
+        Q_ASSERT(!components.isEmpty());
+        ret = components.constFirst().name() + QStringLiteral(" - ") + m_appdata.name();
+    } else
         ret = m_appdata.name();
     return ret;
 }
@@ -70,10 +63,7 @@ QString AppPackageKitResource::longDescription()
 static QIcon componentIcon(const AppStream::Component &comp)
 {
     QIcon ret;
-    const auto icons = comp.icons();
-    if (icons.isEmpty()) {
-        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
-    } else foreach(const AppStream::Icon &icon, icons) {
+    foreach(const AppStream::Icon &icon, comp.icons()) {
         QStringList stock;
         switch(icon.kind()) {
             case AppStream::Icon::KindLocal:
@@ -82,15 +72,18 @@ static QIcon componentIcon(const AppStream::Component &comp)
             case AppStream::Icon::KindCached:
                 ret.addFile(icon.url().toLocalFile(), icon.size());
                 break;
-            case AppStream::Icon::KindStock:
-                stock += icon.name();
+            case AppStream::Icon::KindStock: {
+                const auto ret = QIcon::fromTheme(icon.name());
+                if (!ret.isNull())
+                    return ret;
                 break;
+            }
             default:
                 break;
         }
-        if (ret.isNull() && !stock.isEmpty()) {
-            ret = QIcon::fromTheme(stock.first());
-        }
+    }
+    if (ret.isNull()) {
+        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     }
     return ret;
 }
@@ -138,6 +131,21 @@ QUrl AppPackageKitResource::homepage()
     return m_appdata.url(AppStream::Component::UrlKindHomepage);
 }
 
+QUrl AppPackageKitResource::helpURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindHelp);
+}
+
+QUrl AppPackageKitResource::bugURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindBugtracker);
+}
+
+QUrl AppPackageKitResource::donationURL()
+{
+    return m_appdata.url(AppStream::Component::UrlKindDonation);
+}
+
 bool AppPackageKitResource::isTechnical() const
 {
     static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
@@ -191,32 +199,21 @@ void AppPackageKitResource::fetchChangelog()
 
 void AppPackageKitResource::invokeApplication() const
 {
-    auto trans = PackageKit::Daemon::getFiles({installedPackageId()});
-    connect(trans, &PackageKit::Transaction::files, this, [this](const QString &/*packageID*/, const QStringList &filenames) {
-        const auto allServices = QStandardPaths::locateAll(QStandardPaths::ApplicationsLocation, m_appdata.id());
-        if (!allServices.isEmpty()) {
-            const auto packageServices = kFilter<QStringList>(allServices, [filenames](const QString &file) { return filenames.contains(file); });
-            QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {packageServices});
-        } else {
-            const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
-            const auto packageExecutables = kFilter<QStringList>(allServices, [filenames](const QString &exe) { return filenames.contains(QLatin1Char('/') + exe); });
-            if (!packageExecutables.isEmpty()) {
-                QProcess::startDetached(exes.constFirst());
-            } else {
-                const auto locations = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
-                const auto desktopFiles = kFilter<QStringList>(filenames, [locations](const QString &exe) {
-                    for (const auto &location: locations) {
-                        if (exe.startsWith(location))
-                            return exe.contains(QLatin1String(".desktop"));
-                    }
-                    return false;
-                });
-                if (!desktopFiles.isEmpty()) {
-                    QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), { desktopFiles });
-                }
-            }
-            qWarning() << "Could not find any executables" << exes << filenames;
-        }
-    });
+    const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
+    if (exes.isEmpty()) {
+        const auto servicePath = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, m_appdata.id());
+        QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
+    } else {
+        QProcess::startDetached(exes.constFirst());
+    }
 }
 
+QDate AppPackageKitResource::releaseDate() const
+{
+    if (!m_appdata.releases().isEmpty()) {
+        auto release = m_appdata.releases().constFirst();
+        return release.timestamp().date();
+    }
+
+    return {};
+}
