@@ -93,33 +93,25 @@ void PKTransaction::trigger(PackageKit::Transaction::TransactionFlags flags)
     connect(m_trans.data(), &PackageKit::Transaction::mediaChangeRequired, this, &PKTransaction::mediaChange);
     connect(m_trans.data(), &PackageKit::Transaction::requireRestart, this, &PKTransaction::requireRestart);
     connect(m_trans.data(), &PackageKit::Transaction::repoSignatureRequired, this, &PKTransaction::repoSignatureRequired);
-    connect(m_trans.data(), &PackageKit::Transaction::percentageChanged, this, &PKTransaction::progressChanged);
-    connect(m_trans.data(), &PackageKit::Transaction::statusChanged, this, &PKTransaction::statusChanged);
+    connect(m_trans.data(), &PackageKit::Transaction::itemProgress, this, &PKTransaction::progressChanged);
     connect(m_trans.data(), &PackageKit::Transaction::eulaRequired, this, &PKTransaction::eulaRequired);
     connect(m_trans.data(), &PackageKit::Transaction::allowCancelChanged, this, &PKTransaction::cancellableChanged);
     
     setCancellable(m_trans->allowCancel());
 }
 
-void PKTransaction::statusChanged()
+void PKTransaction::progressChanged(const QString &id, PackageKit::Transaction::Status status, uint percentage)
 {
-    setStatus(m_trans->status() == PackageKit::Transaction::StatusDownload ? Transaction::DownloadingStatus : Transaction::CommittingStatus);
-    progressChanged();
-}
+    PackageKitResource * res = qobject_cast<PackageKitResource*>(resource());
+    if (!res->allPackageNames().contains(PackageKit::Daemon::packageName(id)))
+        return;
 
-int percentageWithStatus(PackageKit::Transaction::Status status, uint percentage);
+    setProgress(percentage);
 
-void PKTransaction::progressChanged()
-{
-    auto percent = m_trans->percentage();
-    if (percent == 101) {
-        qWarning() << "percentage cannot be calculated";
-        percent = 50;
-    }
-
-    const auto processedPercentage = percentageWithStatus(m_trans->status(), qBound<int>(0, percent, 100));
-    if (processedPercentage >= 0)
-        setProgress(processedPercentage);
+    if (status == PackageKit::Transaction::StatusDownload)
+        setStatus(Transaction::DownloadingStatus);
+    else
+        setStatus(Transaction::CommittingStatus);
 }
 
 void PKTransaction::cancellableChanged()
@@ -142,7 +134,6 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
 {
     Q_UNUSED(runtime)
     const bool cancel = !m_proceedFunctions.isEmpty() || exit == PackageKit::Transaction::ExitCancelled;
-    const bool failed = exit == PackageKit::Transaction::ExitFailed;
     const bool simulate = m_trans->transactionFlags() & PackageKit::Transaction::TransactionFlagSimulate;
 
     disconnect(m_trans, nullptr, this, nullptr);
@@ -150,7 +141,7 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
 
     const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
 
-    if (!cancel && !failed && simulate) {
+    if (!cancel && simulate) {
         auto packagesToRemove = m_newPackageStates.value(PackageKit::Transaction::InfoRemoving);
         QMutableListIterator<QString> i(packagesToRemove);
         QSet<AbstractResource*> removedResources;
@@ -173,7 +164,7 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
             }
             msg += QStringLiteral("</li></ul>");
 
-            Q_EMIT proceedRequest(i18n("Confirm..."), i18np("To proceed with this action, the following package needs removal:\n%2", "To proceed with this action, the following packages need removal:\n%2", packagesToRemove.count(), msg));
+            Q_EMIT proceedRequest(i18n("Confirm package removal"), i18np("This action will also remove the following package:\n%2", "This action will also remove the following packages:\n%2", packagesToRemove.count(), msg));
         } else {
             proceed();
         }
@@ -181,10 +172,7 @@ void PKTransaction::cleanup(PackageKit::Transaction::Exit exit, uint runtime)
     }
 
     this->submitResolve();
-    if (failed)
-        setStatus(Transaction::DoneWithErrorStatus);
-    else
-        setStatus(Transaction::CancelledStatus);
+    setStatus(Transaction::CancelledStatus);
 }
 
 void PKTransaction::processProceedFunction()
@@ -222,15 +210,13 @@ void PKTransaction::packageResolved(PackageKit::Transaction::Info info, const QS
 void PKTransaction::submitResolve()
 {
     QStringList needResolving;
-    foreach(const auto &pkgids, m_newPackageStates) {
-        foreach(const auto &pkgid, pkgids) {
-            needResolving += PackageKit::Daemon::packageName(pkgid);
-        }
+    const auto pkgids = m_newPackageStates.value(PackageKit::Transaction::InfoFinished);
+    foreach(const auto pkgid, pkgids) {
+        needResolving += PackageKit::Daemon::packageName(pkgid);
     }
+    const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
 
     if (!needResolving.isEmpty()) {
-        needResolving.removeDuplicates();
-        const auto backend = qobject_cast<PackageKitBackend*>(resource()->backend());
         backend->clearPackages(needResolving);
         backend->resolvePackages(needResolving);
     }
