@@ -40,6 +40,8 @@ class PKTransaction : public Transaction
         void start();
 
     private:
+        void processProceedFunction();
+
         void cleanup(PackageKit::Transaction::Exit, uint);
         void errorFound(PackageKit::Transaction::Error err, const QString& error);
         void mediaChange(PackageKit::Transaction::MediaType media, const QString& type, const QString& text);
@@ -49,12 +51,20 @@ class PKTransaction : public Transaction
         void cancellableChanged();
         void packageResolved(PackageKit::Transaction::Info info, const QString& packageId);
         void submitResolve();
+        void repoSignatureRequired(const QString &packageID,
+                                    const QString &repoName,
+                                    const QString &keyUrl,
+                                    const QString &keyUserid,
+                                    const QString &keyId,
+                                    const QString &keyFingerprint,
+                                    const QString &keyTimestamp,
+                                    PackageKit::Transaction::SigType type);
 
         void trigger(PackageKit::Transaction::TransactionFlags flags);
         QPointer<PackageKit::Transaction> m_trans;
         const QVector<AbstractResource*> m_apps;
         QSet<QString> m_pkgnames;
-        QVector<QString> m_requiredEula;
+        QVector<std::function<PackageKit::Transaction*()>> m_proceedFunctions;
 
         QMap<PackageKit::Transaction::Info, QStringList> m_newPackageStates;
 };
