@@ -53,18 +53,6 @@
 
 DISCOVER_BACKEND_PLUGIN(PackageKitBackend)
 
-template <typename T, typename W>
-static void setWhenAvailable(const QDBusPendingReply<T>& pending, W func, QObject* parent)
-{
-    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(pending, parent);
-    QObject::connect(watcher, &QDBusPendingCallWatcher::finished,
-                    parent, [func](QDBusPendingCallWatcher* watcher) {
-                        watcher->deleteLater();
-                        QDBusPendingReply<T> reply = *watcher;
-                        func(reply.value());
-                    });
-}
-
 QString PackageKitBackend::locateService(const QString &filename)
 {
     return QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("applications/")+filename);
@@ -72,14 +60,13 @@ QString PackageKitBackend::locateService(const QString &filename)
 
 PackageKitBackend::PackageKitBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
-    , m_appdata(new AppStream::Pool)
     , m_updater(new PackageKitUpdater(this))
     , m_refresher(nullptr)
     , m_isFetching(0)
     , m_reviews(AppStreamIntegration::global()->reviews())
 {
     QTimer* t = new QTimer(this);
-    connect(t, &QTimer::timeout, this, &PackageKitBackend::checkForUpdates);
+    connect(t, &QTimer::timeout, this, &PackageKitBackend::refreshDatabase);
     t->setInterval(60 * 60 * 1000);
     t->setSingleShot(false);
     t->start();
@@ -94,12 +81,17 @@ PackageKitBackend::PackageKitBackend(QObject* parent)
 
     SourcesModel::global()->addSourcesBackend(new PackageKitSourcesBackend(this));
 
+    QString error;
+    const bool b = m_appdata.load(&error);
     reloadPackageList();
 
-    setWhenAvailable(PackageKit::Daemon::getTimeSinceAction(PackageKit::Transaction::RoleRefreshCache), [this](uint timeSince) {
-        if (timeSince > 3600)
-            checkForUpdates();
-    }, this);
+    if (!b && m_packages.packages.isEmpty()) {
+        qWarning() << "Could not open the AppStream metadata pool" << error;
+
+        QTimer::singleShot(0, this, [this]() {
+            Q_EMIT passiveMessage(i18n("Please make sure that Appstream is properly set up on your system"));
+        });
+    }
 }
 
 PackageKitBackend::~PackageKitBackend() = default;
@@ -129,18 +121,7 @@ void PackageKitBackend::reloadPackageList()
         disconnect(m_refresher.data(), &PackageKit::Transaction::finished, this, &PackageKitBackend::reloadPackageList);
     }
 
-    QString error;
-    m_appdata.reset(new AppStream::Pool);
-    const bool b = m_appdata->load(&error);
-    if (!b && m_packages.packages.isEmpty()) {
-        qWarning() << "Could not open the AppStream metadata pool" << error;
-
-        QTimer::singleShot(0, this, [this]() {
-            Q_EMIT passiveMessage(i18n("Please make sure that Appstream is properly set up on your system"));
-        });
-    }
-
-    const auto components = m_appdata->components();
+    const auto components = m_appdata.components();
     QStringList neededPackages;
     neededPackages.reserve(components.size());
     foreach(const AppStream::Component& component, components) {
@@ -149,9 +130,8 @@ void PackageKitBackend::reloadPackageList()
 
         const auto pkgNames = component.packageNames();
         if (pkgNames.isEmpty()) {
-            auto launchable = component.launchable(AppStream::Launchable::KindDesktopId);
-            if (component.kind() == AppStream::Component::KindDesktopApp && !launchable.entries().isEmpty()) {
-                const QString file = locateService(launchable.entries().constFirst());
+            if (component.kind() == AppStream::Component::KindDesktopApp) {
+                const QString file = locateService(component.desktopId());
                 if (!file.isEmpty()) {
                     auto trans = PackageKit::Daemon::searchFiles(file);
                     connect(trans, &PackageKit::Transaction::package, this, [trans](PackageKit::Transaction::Info info, const QString &packageID){
@@ -164,7 +144,6 @@ void PackageKitBackend::reloadPackageList()
                             const auto pkgid = pkgidVal.toString();
                             acquireFetching(true);
                             auto res = addComponent(component, {PackageKit::Daemon::packageName(pkgid)});
-                            res->clearPackageIds();
                             res->addPackageId(PackageKit::Transaction::InfoInstalled, pkgid, true);
                             acquireFetching(false);
                         }
@@ -182,15 +161,8 @@ void PackageKitBackend::reloadPackageList()
     }
 
     acquireFetching(false);
-    if (!neededPackages.isEmpty()) {
-        neededPackages.removeDuplicates();
-        resolvePackages(neededPackages);
-    } else {
-        qDebug() << "empty appstream db";
-        if (PackageKit::Daemon::backendName() == QLatin1String("aptcc") || PackageKit::Daemon::backendName().isEmpty()) {
-            checkForUpdates();
-        }
-    }
+    neededPackages.removeDuplicates();
+    resolvePackages(neededPackages);
 }
 
 AppPackageKitResource* PackageKitBackend::addComponent(const AppStream::Component& component, const QStringList& pkgNames)
@@ -198,14 +170,8 @@ AppPackageKitResource* PackageKitBackend::addComponent(const AppStream::Componen
     Q_ASSERT(isFetching());
     Q_ASSERT(!pkgNames.isEmpty());
 
-
-    AppPackageKitResource* res = qobject_cast<AppPackageKitResource*>(m_packages.packages[component.id()]);
-    if (!res) {
-        res = new AppPackageKitResource(component, pkgNames.at(0), this);
-        m_packages.packages[component.id()] = res;
-    } else {
-        res->clearPackageIds();
-    }
+    const auto res = new AppPackageKitResource(component, pkgNames.at(0), this);
+    m_packages.packages[component.id()] = res;
     foreach (const QString& pkg, pkgNames) {
         m_packages.packageToApp[pkg] += component.id();
     }
@@ -303,11 +269,6 @@ void PackageKitBackend::includePackagesToAdd()
         foreach(const auto &pkg, pkgs) {
             auto res = m_packages.packages.take(pkg);
             if (res) {
-                if (AppPackageKitResource* ares = qobject_cast<AppPackageKitResource*>(res)) {
-                    for(const auto &ext: res->extends())
-                        m_packages.extendedBy[ext].removeAll(ares);
-                }
-
                 emit resourceRemoved(res);
                 res->deleteLater();
             }
@@ -337,11 +298,11 @@ void PackageKitBackend::packageDetails(const PackageKit::Details& details)
 
 QSet<AbstractResource*> PackageKitBackend::resourcesByPackageName(const QString& name) const
 {
-    return resourcesByPackageNames<QSet<AbstractResource*>, QVector<QString>>({name});
+    return resourcesByPackageNames<QSet<AbstractResource*>>({name});
 }
 
-template <typename T, typename Q>
-T PackageKitBackend::resourcesByPackageNames(const Q &pkgnames) const
+template <typename T>
+T PackageKitBackend::resourcesByPackageNames(const QStringList &pkgnames) const
 {
     T ret;
     ret.reserve(pkgnames.size());
@@ -357,13 +318,17 @@ T PackageKitBackend::resourcesByPackageNames(const Q &pkgnames) const
 }
 
 void PackageKitBackend::checkForUpdates()
+{
+    refreshDatabase();
+}
+
+void PackageKitBackend::refreshDatabase()
 {
     if (!m_refresher) {
         acquireFetching(true);
         m_refresher = PackageKit::Daemon::refreshCache(false);
         connect(m_refresher.data(), &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
         connect(m_refresher.data(), &PackageKit::Transaction::finished, this, [this]() {
-            m_refresher = nullptr;
             reloadPackageList();
             acquireFetching(false);
         });
@@ -374,7 +339,7 @@ void PackageKitBackend::checkForUpdates()
 
 QList<AppStream::Component> PackageKitBackend::componentsById(const QString& id) const
 {
-    return m_appdata->componentsById(id);
+    return m_appdata.componentsById(id);
 }
 
 ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters& filter)
@@ -387,7 +352,7 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
     } else if (filter.search.isEmpty()) {
         return new ResultsStream(QStringLiteral("PackageKitStream-all"), kFilter<QVector<AbstractResource*>>(m_packages.packages, [](AbstractResource* res) { return !res->isTechnical(); }));
     } else {
-        const QList<AppStream::Component> components = m_appdata->search(filter.search);
+        const QList<AppStream::Component> components = m_appdata.search(filter.search);
         const QStringList ids = kTransform<QStringList>(components, [](const AppStream::Component& comp) { return comp.id(); });
         auto stream = new ResultsStream(QStringLiteral("PackageKitStream-search"));
         if (!ids.isEmpty()) {
@@ -407,7 +372,7 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
             if (status == PackageKit::Transaction::Exit::ExitSuccess) {
                 const auto packageId = stream->property("packageId");
                 if (!packageId.isNull()) {
-                    const auto res = resourcesByPackageNames<QVector<AbstractResource*>, QVector<QString>>({PackageKit::Daemon::packageName(packageId.toString())});
+                    const auto res = resourcesByPackageNames<QVector<AbstractResource*>>({PackageKit::Daemon::packageName(packageId.toString())});
                     stream->resourcesFound(kFilter<QVector<AbstractResource*>>(res, [ids](AbstractResource* res){ return !ids.contains(res->appstreamId()); }));
                 }
             }
@@ -420,7 +385,9 @@ ResultsStream* PackageKitBackend::search(const AbstractResourcesBackend::Filters
 ResultsStream * PackageKitBackend::findResourceByPackageName(const QUrl& url)
 {
     AbstractResource* pkg = nullptr;
-    if (url.scheme() == QLatin1String("appstream")) {
+    if (url.host().isEmpty())
+        passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
+    else if (url.scheme() == QLatin1String("appstream")) {
         static const QMap<QString, QString> deprecatedAppstreamIds = {
             { QStringLiteral("org.kde.krita.desktop"), QStringLiteral("krita.desktop") },
             { QStringLiteral("org.kde.digikam.desktop"), QStringLiteral("digikam.desktop") },
@@ -443,7 +410,7 @@ ResultsStream * PackageKitBackend::findResourceByPackageName(const QUrl& url)
                 }
             }
             if (!pkg)
-                qDebug() << "could not find" << host << deprecatedHost;
+                qWarning() << "could not find" << host << deprecatedHost;
         }
     }
     return new ResultsStream(QStringLiteral("PackageKitStream-url"), pkg ? QVector<AbstractResource*>{pkg} : QVector<AbstractResource*>{});
@@ -590,6 +557,23 @@ void PackageKitBackend::performDetailsFetch()
     PackageKit::Transaction* transaction = PackageKit::Daemon::getDetails(ids);
     connect(transaction, &PackageKit::Transaction::details, this, &PackageKitBackend::packageDetails);
     connect(transaction, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
+
+    QSharedPointer<QMap<QString, int>> packageDependencies(new QMap<QString, int>);
+    auto trans = PackageKit::Daemon::dependsOn(ids);
+    connect(trans, &PackageKit::Transaction::package, this, [packageDependencies](PackageKit::Transaction::Info /*info*/, const QString &packageID, const QString &/*summary*/) {
+        (*packageDependencies)[packageID] += 1;
+    });
+    connect(trans, &PackageKit::Transaction::finished, this, [this, packageDependencies](PackageKit::Transaction::Exit /*status*/) {
+        auto pkgDeps = (*packageDependencies);
+
+        for (auto it = pkgDeps.constBegin(), itEnd = pkgDeps.constEnd(); it != itEnd; ++it) {
+            const auto resources = resourcesByPackageName(PackageKit::Daemon::packageName(it.key()));
+            for(auto resource : resources) {
+                auto pkres = qobject_cast<PackageKitResource*>(resource);
+                pkres->setDependenciesCount(it.value());
+            }
+        }
+    });
 }
 
 void PackageKitBackend::checkDaemonRunning()
