@@ -75,7 +75,9 @@ void PackageKitUpdater::prepare()
 void PackageKitUpdater::setupTransaction(PackageKit::Transaction::TransactionFlags flags)
 {
     m_packagesRemoved.clear();
-    m_transaction = PackageKit::Daemon::updatePackages(involvedPackages(m_toUpgrade).toList(), flags);
+    auto pkgs = involvedPackages(m_toUpgrade).toList();
+    pkgs.sort();
+    m_transaction = PackageKit::Daemon::updatePackages(pkgs, flags);
     m_isCancelable = m_transaction->allowCancel();
 
     connect(m_transaction.data(), &PackageKit::Transaction::finished, this, &PackageKitUpdater::finished);
@@ -88,6 +90,9 @@ void PackageKitUpdater::setupTransaction(PackageKit::Transaction::TransactionFla
     connect(m_transaction.data(), &PackageKit::Transaction::allowCancelChanged, this, &PackageKitUpdater::cancellableChanged);
     connect(m_transaction.data(), &PackageKit::Transaction::percentageChanged, this, &PackageKitUpdater::percentageChanged);
     connect(m_transaction.data(), &PackageKit::Transaction::itemProgress, this, &PackageKitUpdater::itemProgress);
+    connect(m_transaction.data(), &PackageKit::Transaction::speedChanged, this, [this] {
+        Q_EMIT downloadSpeedChanged(downloadSpeed());
+    });
 }
 
 QSet<AbstractResource*> PackageKitUpdater::packagesForPackageId(const QSet<QString>& pkgids) const
@@ -387,3 +392,8 @@ double PackageKitUpdater::updateSize() const
     }
     return ret;
 }
+
+quint64 PackageKitUpdater::downloadSpeed() const
+{
+    return m_transaction ? m_transaction->speed() : 0;
+}
