@@ -42,6 +42,7 @@ public:
         bool cancelable = false;
         foreach(auto updater, m_allUpdaters) {
             connect(updater, &AbstractBackendUpdater::progressingChanged, this, &UpdateTransaction::slotProgressingChanged);
+            connect(updater, &AbstractBackendUpdater::downloadSpeedChanged, this, &UpdateTransaction::slotDownloadSpeedChanged);
             connect(updater, &AbstractBackendUpdater::progressChanged, this, &UpdateTransaction::slotUpdateProgress);
             connect(updater, &AbstractBackendUpdater::proceedRequest, this, &UpdateTransaction::processProceedRequest);
             connect(updater, &AbstractBackendUpdater::cancelableChanged, this, [this](bool cancelable){ if (cancelable) setCancellable(true); });
@@ -94,6 +95,15 @@ public:
         setProgress(total / m_allUpdaters.count());
     }
 
+    void slotDownloadSpeedChanged()
+    {
+        quint64 total = 0;
+        foreach(AbstractBackendUpdater* updater, m_allUpdaters) {
+            total += updater->downloadSpeed();
+        }
+        setDownloadSpeed(total);
+    }
+
     QVariant icon() const override { return QStringLiteral("update-low"); }
     QString name() const override { return i18n("Update"); }
 
@@ -173,9 +183,6 @@ void ResourcesUpdatesModel::updateAll()
         delete m_transaction;
 
         const auto updaters = kFilter<QVector<AbstractBackendUpdater*>>(m_updaters, [](AbstractBackendUpdater* u) {return u->hasUpdates(); });
-        if (updaters.isEmpty()) {
-            return;
-        }
 
         m_transaction = new UpdateTransaction(this, updaters);
         setTransaction(m_transaction);
